function X = aggregx(initialPop, popGrowth, gr, xv)
% aggreg: Individual -> aggregate level; bgp only
% ---------------------------------------
% TASK:
%  Individual -> aggregate level; bgp only
% IN:
%  initialPop   = initial population
%  popGrowth    = population growth rate + 1
%  gr               = growth rate of per capita values + 1
%  xv           = bgp profile of a representative household, e.g., c(age)
% OUT:
%  aggregate x

% ERRORS:
%
% TEST:
%  t_aggrx
% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

   T = length(xv);


% *** Population size ***
%  earlier generations are smaller

   popul = seqm(initialPop, 1/popGrowth, T);

% *** Factor to adjust for growth ***

   grFactor = seqm(1, 1/gr, T);

% *** Aggregation ***
%  First compute the vectors of individual supplies:

   xInd = popul .* grFactor .* xv;

%  Then sum over ages:
   X = sum(xInd);


% *** end function ***
