function [a, sT] = hhassets(c,wt,h,x,  h1,a1, w, r, tl,tc, Tr,...
    xDeduct,xEarn,sx, B1,tBequ1,BTwTax)
% Compute hh asset profile and terminal savings
% ---------------------------------------
% IN:
%   obvious
%   Bequest variables:
%   - B1 received at *beginning* of tBequ1
% OUT:
%   a(1:T)  = asset profile
%   sT      = terminal savings; a(T+1)

% REM:
%

% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

    T = length(c);

% *************  ASSET PROFILE  ****************


    Income = netearn(w,h,wt, x,xEarn,tl,xDeduct) + Tr;
    Expend = c.*(1+tc) + (1 - sx).*(1-xEarn).*x;

    Expend(T) = Expend(T) + BTwTax;

    a = zeros(1,T+1);
    a(1) = a1;

    for t = 1 : T
        if t == tBequ1
            a(t) = a(t) + B1;
        end
        a(t+1) = a(t)*(1+r(t)) + Income(t) - Expend(t);
    end


% **************  TERMINAL SAVINGS  *************

    % sT excludes BT; should be 0
    sT = a(T+1);
    a  = a(1:T);

    % *** Checking not always desirable! ***
    if 0
        if abs(sT) > 1e-3;
            tmp = sprintf('HhAssets: s(T)=%6.3f -- BT=%6.3f', sT, BTwTax);
            disp(tmp);
            warnmsg('Terminal savings non-zero');
        end
        disp(' Age  Income  Expend   Diff. a(t)*R(t) r(t)   a(t+1)');
        for i = 1 : T
            diff = Income(i) - Expend(i);
            if i < T
                aNext = a(i+1);
            else
                aNext = sT;
            end
            tmp = sprintf('%3i %7.3f %7.3f %7.3f %7.3f %7.3f %7.3f', i, Income(i),...
                Expend(i), diff, a(i)*(1+r(i)), r(i), aNext );
            disp(tmp)
        end
        disp(' ')
        pvIncome = prvalue(Income, r);
        pvExpend = prvalue(Expend, r);
        if distance(pvIncome, pvExpend) > 1e-4
            disp('Present values differ:')
            tmp = sprintf('PV(Income): %7.3f    PV(Expend): %7.3f', ...
                pvIncome, pvExpend);
            disp(tmp)
            disp(' ')
        end
    end



% *** end function ***


