function [kMin, kMax] = kbounds(rMin, rMax, tk,kDeduct,ddk)
% Find interval of K/L s.t. interest rate bounded by [rMin,rMax]
% ---------------------------------------
% IN:
%   rMin, rMax
%       interest bounds; per period; net of taxes and depreciation
%   tk,tw,kDeduct
%       tax policies
% OUT:
%   K/L bounds


% ERRORS:
%
% TEST:
%   Call:  kbounds(0.01, 0.19, 0.1, 0.2, 0)
% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

% *** GLOBALS ***

    global aa A


% *******  INPUT CHECK  ********

    if rMin <= 0
        abort('r must be positive')
    end


% ****** COMPUTATION ******

    kMin = ...
    ( ( rMax + (1-kDeduct.*tk).*ddk ) ./ (1-tk) ./ aa ./ A ) .^ (1/(aa-1));
    kMax = ...
    ( ( rMin + (1-kDeduct.*tk).*ddk ) ./ (1-tk) ./ aa ./ A ) .^ (1/(aa-1));


% ********  CHECK  *********

	if 1
        r1 = rnet(kMax, tk, kDeduct, ddk);
        r2 = rnet(kMin, tk, kDeduct, ddk);

	    if abs(r1-rMin) > 1e-3  |  abs(r2-rMax) > 1e-3
	        r1
	        rMin
	        r2
	        rMax
	        abort('Incorrect computation')
	    end
	end

% *** end function ***

