function [grM,rGrM,lM] = matchval(dbg);
% matchVal: Compute values to be matched by bgp/calibration
% ---------------------------------------
% TASK:
%   Compute values to be matched by bgp/calibration
%   File contains calibration targets not currently used

% IN:
%   T
%       life time

% OUT:
%  Values to be matched by model
%  grM      growth rate of per capita output
%  rGrM     before tax interest rate
%  lM       average leisure share

% AUTHOR: Lutz Hendricks, 1995-97
% ---------------------------------------

% *** GLOBALS ***

global ddk aa
global yearsOfLife iniAge yPerPd
fName = 'MatchVal';


% **********************  OJT  ******************************
%   Set average values for age groups 20-24,<35,<45,<55,<65
%   Measured in fraction of OBSERVED work time.
%   Juster/Stafford (1985) and Mincer (1991).
%   Probably not very accurate!
if 0
    ojtYears = [ 24, 34, 44, 54, 64 ] - iniAge + 1;
    ojtYear1 = 20 - iniAge + 1;
    ojt = [ 0.25, 0.165, 0.118, 0.03, 0.03 ];
end


% ***************  WAGES  *******************

    % From Owen 1986. These are before taxes, but with proportional
    % taxation that does not affect the growth of wages.
    % Age groups: 20-24, -44 , -64, 65+
    if 0
       wageYears = [ [24, 44, 64]-iniAge+1, yearsOfLife ];
       wageYear1 = 20 - iniAge + 1;
       wages = [ 1, 2.2, 3.5, 3.5 ];
    end

    % ** From Fullerton/Rogers (1993)
    if 0
        %wageYears = [ [24, 34, 44, 54, 64,]-iniAge+1, yearsOfLife ];
        %wages       = [ 1, 1.2,1.4,1.5,1.5, 1.1 ];
        wageYears = [ [24, 44, 64]-iniAge+1, yearsOfLife ];
        wageYear1 = 20 - iniAge + 1;
        % Without growth adjustment
        % wages = [ 1, 1.4, 1.5, 1.1 ];
        % With growth adjustment
        wages = [ 1, (1.34+1.9)/2, (2.47+2.84)/2, 2.52 ];
    end

    % ***********  FULLERTON / ROGERS with growth adjustment  *******
    if 0
        wageYears = [ [24, 34, 44, 54, 64]-iniAge+1, yearsOfLife ];
        wageYear1 = 20 - iniAge + 1;
        wages = [ 1, 1.31, 1.85, 2.41, 2.77, 2.54 ];
    end


    % ****** Welch (1979) **********
    if 0
        wageYears = [ [24, 44, 64]-iniAge+1, yearsOfLife ];
        wageYear1 = 20 - iniAge + 1;
        %wages = [ 1,  ];
    end


% ********  MARKET TIME  *********
% Match to 1-l
if 0
    hYears = [ [24, 44, 64]-iniAge+1, yearsOfLife ];
    hYear1 = 20 - iniAge + 1;
    % ** Without correction for education:
    %    hMean =  [ 25.7, 30.2, 25.7, 4];
    % ** With correction for education:
    %   hMean =  [ 36.4, 31.9, 25.7, 4];
    % ** Juster/Stafford 1985; market time incl. OJT and education
    hMean = [ 1, 1.06, 0.76, 0.12 ];
    hMean = hMean ./ hMean(1);
end

% *********  EARNINGS  **********
if 0
    if 0
        % *******  OWEN 1985  ********
        % Compute earnings from labor supply and wages, where labor supply
        % includes time for OJT
        earnYears = [ [24, 44, 64]-iniAge+1, yearsOfLife ];
        earnYear1 = 20 - iniAge + 1;
%        hours = [ 32, 30.2, 25.7, 4 ];
%        wages = [ 1,  2.4,  3.6,  3.6 ];
        % Average earnings for age intervals
        earn  = [ 1, 2.77, 3.64, 0.56 ];
        %   earnGrowth  = [ earn(2)/earn(1), earn(3)/earn(2), earn(4)/earn(3) ];
    end

    if 1
        % ********  FULLERTON/ROGERS 1993  **********
        %earnYears = [ [24,34,44,54,64,]-iniAge+1, yearsOfLife ];
        earnYear1 = 20 - iniAge + 1;
        earnYears = wageYears;
        %earn = [ 1, 1.48, 1.14, 0.13 ];

        earn = wages .* hMean;
    end

    % ******  FULLERTON/ROGERS with growth adjustment  **********
    if 0
        earnYears = wageYears;
        earnYear1 = 20 - iniAge + 1;
        earn = [ 1, 1.45, 2.17, 2.81, 0.31 ];
    end
end



% ***************  GROWTH RATE  *******************

    grM = 1.017 ^ yPerPd;


% ********************  INTEREST RATE  *****************
% Before taxes. After depreciation. Matched to the rate of return on stocks.

    rGrM = 1.065 ^ yPerPd - 1;


% *******  LEISURE SHARE  ******
% Juster/Stafford (1991, Table 1)
    lM = 0.56;


% *** end function ***

