function res = polcomp(tw,tk,tc,to,ts,RR,GY,TrY,DY,sx, tax0,tax9,taxE,...
    taxAdj,taxAdjTP,N)
% Compare policies with specification in tax0 and tax9
% ---------------------------------------
% IN:
%   policy paths (1xN)
%       sx may be scalar
%   tax0    = must contain the CORRECT values for the endogenous policy!
%   tax9
%   taxAdjTP
%   taxAdj
%   If ts and RR are scalar 0, they are ignored.
%   If UNCHANGED is specified, the policy may either have the value UNCHANGED
%       or it may have the value of the previous period
% OUT:
%   res
%       1=OK, 0=Difference

% CHANGE:
%   compare ssx, twx
% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

% *** GLOBALS ***

global tkAdjustsG twAdjustsG GYAdjustsG TrYAdjustsG DYAdjustsG tcAdjustsG
global toAdjustsG sxAdjustsG
global UNCHANGED
TOLER = 1e-5;


% *************  INPUT CHECK  ************

    TP = size(tax9,2);
    TPidx = 1:TP;
    TPNidx = TP+1:N;

%    [tw0,tk0,TrY0,GY0,tc0,to0,DY0,sx0,ts0,RR0] = taxvec(tax0);
    [tw9,tk9,TrY9,GY9,tc9,to9,DY9,sx9,ts9,RR9] = taxvec(tax9);
    [twE,tkE,TrYE,GYE,tcE,toE,DYE,sxE,tsE,RRE] = taxvec(taxE);

    N = length(tw);
    if length(sx) == 1
        sx = sx .* ones(1,N);
    end
    polV = [ tw;tk;TrY;GY;tc;to;DY;sx ];


% *************  CONSTRUCT ARRAYS FOR EASIER ACCESS  ***********

    % ** Policy specifications
    % ** No of policy variables ignoring SS
    polNo = size(polV,1);
    spec9 = tax9(1:polNo,:);
    specE = taxE(1:polNo);

    % ** Actual policies
    pol0 = tax0(1:polNo);
    pol9 = polV(:,TPidx);
    polE = polV(:,TPNidx);


% *************  PERIODS 1:TP  *************************

    fehler = 0;
    for i = 1 : polNo
        policy = pol9(i,:);
        % ** Everything is fine if policy is set to UNCHANGED or is endo-
        % ** genous.
        if  any( policy ~= UNCHANGED )  &  taxAdjTP ~= i
            if  any(spec9(i,:) ~= UNCHANGED)
                % ** Unchanged is NOT specified
                if  notequal( policy, spec9(i,:), TOLER )
                    warnmsg([ 'PolComp: Difference in TP policy ', int2str(i) ])
                    fehler = 1;
                end
            else
                % ** Unchanged is specified; compare with pol0
                if  notequal( policy, pol0(i), TOLER )
                    warnmsg([ 'PolComp: Difference in TP policy ', int2str(i) ])
                    fehler = 1;
                end
            end
        end
    end



% *************  PERIODS AFTER TP  *************************

    for i = 1 : polNo
        policy = polE(i,:);
        % ** Everything is fine if policy is set to UNCHANGED or is endo-
        % ** genous.
        if  any( policy ~= UNCHANGED )  &  taxAdj ~= i
            if  any(specE(i) ~= UNCHANGED)
                % ** Unchanged is NOT specified
                if  notequal( policy, specE(i), TOLER )
                    warnmsg([ 'PolComp: Difference in policy ', int2str(i) ])
                    disp('UNCHANGED not specified')
                    policy
                    specE(i)
                    fehler = 1;
                end
            else
                % ** Unchanged is specified; compare with pol9(TP)
                if  notequal( policy, pol9(i,TP), TOLER )
                    warnmsg([ 'PolComp: Difference in policy ', int2str(i) ])
                    disp('UNCHANGED is specified')
                    policy
                    pol9(i,TP)
                    fehler = 1;
                end
            end
        end
    end


% ***************  SOCIAL SECURITY  ***************************
% ** ASSUMPTION: RR always adjusts.

    % ** Don't check ts, if ts,RR are scalar 0
    if  (ts~=0 | RR~=0 | length(ts)~=1)
        CheckSS = 1;
    else
        CheckSS = 0;
    end

    if CheckSS==1
        if notequal(ts(TPidx), ts9, TOLER)
            fehler = 1;
        end
        if notequal(ts(TPNidx), tsE, TOLER)
            fehler = 1;
        end
    end


% **************  SHOW RESULT  ************

    if fehler ~= 0
        warnmsg('PolComp: Policies deviate from specification')
        disp('Aborting recommended. Or press any key to continue.')
        pause
    end

% *** end function ***
