function  [gr,r,w, c,x,l,v,Tr] = pPeriod(gr0, r0,w0, c0,x0,l0,v0, Tr0, N);
% Transform into values per period.
% ---------------------------------------
% TASK:
%   Values are given for a length of N periods. E.g., r is the interest rate for N periods.
%   The routine calculates the corresponding values per 1 period.
% IN:
%   gr      = growth factor
%   r,w     = wage and rental rate
%   c, x    = consumption and x flows
%   l, v    = time inputs
%   Tr      = flow of transfers
% OUT:
%   ditto for one period
% ---------------------------------------

% REM:
% - Values that need not be transformed
%   - stocks: K, h
% - Flows are simply divided by N
% - growth factors (gr, 1+r) are raised to the (1/N)th power.
% ERRORS:
%
% TEST:
%
% AUTHOR: Lutz Hendricks, 1994
% ---------------------------------------

% ************  CONSTANTS  *************************************

    F = 1/N;



    gr = gr0 .^ F;
    r  = (1+r0) .^ F - 1;
    w  = w0 ./ N;
    c  = c0 ./ N;
    x  = x0 ./ N;
    l  = l0 ./ N;
    v  = v0 ./ N;
    Tr = Tr0 ./ N;    



% *** end function ***
